<?php
$lang['abbr_length'] = 'L ';
$lang['abbr_width'] = 'B ';
$lang['abbr_height'] = 'H ';
$lang['add'] = 'Legg til';
$lang['addcategory'] = 'Legg til en kategori';
$lang['addfielddef'] = 'Legg til felt';
$lang['adjustable'] = 'Jsuterbart';
$lang['addproduct'] = 'Legg til produkt';
$lang['add_attrib_set'] = 'Legg til attributt';
$lang['add_category_field'] = 'Assosier Felt med Kategori: &quot;%s&quot;';
$lang['add_hierarchy_item'] = 'Legg til hierarki artikkel';
$lang['add_option'] = 'Legg til attributt valg';
$lang['admin_only'] = 'Kan kun administratorer se denne attributten?';
$lang['advanced'] = 'Avansert';
$lang['align_ul'] = 'Topp venstre';
$lang['align_uc'] = 'Topp senter';
$lang['align_ur'] = 'Topp h&oslash;yre';
$lang['align_ml'] = 'Midten venstre';
$lang['align_mc'] = 'Senter';
$lang['align_mr'] = 'Midten h&oslash;yre';
$lang['align_ll'] = 'Bunn venstre';
$lang['align_lc'] = 'Bunn senter';
$lang['align_lr'] = 'Bunn h&oslash;yre';
$lang['all'] = 'Alle';
$lang['allcategories'] = 'Alle kategorier';
$lang['any'] = 'Noen';
$lang['areyousure'] = 'Er du sikker?';
$lang['areyousure_deleteproduct'] = 'Er du virkelig sikker p&aring; at du vil slette dette produktet og all dets tilh&oslash;rende informasjon?';
$lang['ascending'] = 'Stigende';
$lang['attribute_name'] = 'Attributt navn';
$lang['automatic'] = 'Automatisk';
$lang['btn_setecomhandlers'] = 'Sett Ecommerce hendelses behandlere';
$lang['byhierarchytemplates'] = 'Hierarki rappormaler';
$lang['byhierarchytemplate_addedit'] = 'Legg til/rediger Hierarki rappormal';
$lang['cancel'] = 'Avbryt';
$lang['categories'] = 'Kategorier';
$lang['category'] = 'Kategori';
$lang['categoryexists'] = 'En kategori med det navnet eksisterer allerede';
$lang['categorylisttemplates'] = 'Kategoriliste maler';
$lang['categorylisttemplate_addedit'] = 'Legg til/rediger kategori Listemal';
$lang['centimeters'] = 'Centimeter';
$lang['checkbox'] = 'Avkrysningsboks';
$lang['confirm_copyattributes'] = 'Eventuelle eksisterende attributtsett for dette produktet vil bli fjernet. Er du sikker p&aring; at du vil fortsette?';
$lang['confirm_delete_hierarchy_node'] = 'Er du sikker p&aring; at du vil slette denne noden? Alle produkter som bruker denne noden vil bli satt til ingen hierarki';
$lang['confirm_import'] = 'Er du helt sikker p&aring; at du vil gj&oslash;re dette?\n\nFeil innstillinger eller en ugyldig konfigurasjonsfil kan fullstendig &oslash;delegge et n&aring; gyldig og fungerende system.';
$lang['copy'] = 'Kopier';
$lang['copy_attrib_sets'] = 'Kopier attributtsettene';
$lang['copy_category'] = 'Kopier kategori';
$lang['createddate'] = 'Opprettet dato';
$lang['current_value'] = 'N&aring;v&aelig;rende verdi';
$lang['data'] = 'Data ';
$lang['default'] = 'Standard';
$lang['defaulttemplates'] = 'Standard maler';
$lang['default_template_notice'] = '<strong>Merk:</strong> Innholdet i disse teksomr&aring;dene benyttes for &aring; lage standardinnhold i malene n&aring;r du klikker &#039;Legg til mal&#039; i den aktuelle malfanen. &Aring; redigere en av disse tekstomr&aring;dene vil ikke ha umiddelbar effekt p&aring; ditt nettsted.';
$lang['delete'] = 'Slett';
$lang['delete_attribset'] = 'Slett attributt';
$lang['delete_hierarchy_item'] = 'Slett hierarki artikkel';
$lang['descending'] = 'Synkende';
$lang['description'] = 'Beskrivelse';
$lang['destination'] = 'M&aring;l';
$lang['details'] = 'Detaljer';
$lang['detailtemplates'] = 'Detaljmaler';
$lang['detailtemplate_addedit'] = 'Legg til/rediger en detaljmal';
$lang['dimensions'] = 'M&aring;l';
$lang['disabled'] = 'Deaktivert';
$lang['down'] = 'Flytt ned';
$lang['draft'] = 'Kladd';
$lang['dropdown'] = 'Nedtrekk';
$lang['dropdown_options'] = 'Nedtrekksvalg <em>(kun gyldig for nedtrekksfelt)</em><br/><br/><em>(en post pr linje)</em>';
$lang['edit'] = 'Rediger';
$lang['edit_attribset'] = 'Rediger attributt';
$lang['edit_attribsets'] = 'Rediger attributt sett';
$lang['edit_attribsets_for'] = 'Rediger attributt sett for';
$lang['edit_attributes'] = 'Rediger attributter';
$lang['edit_category'] = 'Rediger Kategori';
$lang['edit_category_fields'] = 'Rediger Kategori felter';
$lang['edit_hierarchy_item'] = 'Rediger hierarki artikkel';
$lang['error_attribset_exists'] = 'En attributt med det navnet eksisterer allerede';
$lang['error_duplicate_sku'] = 'Duplikat V.nr.(SKU) funnet';
$lang['error_fieldvalue_empty'] = 'Feltverdien kan ikke v&aelig;re tom';
$lang['error_fileformat'] = 'Filformat rpoblem';
$lang['error_filenotfound'] = 'Fil ikke funnet';
$lang['error_fileopen'] = 'Problem med &aring; &aring;pne filen %s';
$lang['error_invalidparent'] = 'Ugyldig foreldre (en hierarki node kan ikke v&aelig;re sin egen foreldre)';
$lang['error_invalid_name'] = 'Ekstra(custom) feltverdien som ble oppgitt er ugyldig (inneholder ikke-alfanummeriske tegn)';
$lang['error_invalid_value'] = 'Ugyldig verdi oppgitt';
$lang['error_missingparam'] = 'En n&oslash;dvendig parameter mangler eller er ugyldig';
$lang['error_nameused'] = 'En artikkel med det navnet eksisterer allerede';
$lang['error_nofieldtype'] = 'Vennligst velg en felttype';
$lang['error_noname'] = 'Du m&aring; oppgi et navn';
$lang['error_onequantityfield'] = 'Kun et mengde-felt tillatt';
$lang['error_onesubscriptionfield'] = 'Bare ett abonnement felt er tillatt';
$lang['error_permissiondenied'] = 'Tilgang nektet';
$lang['error_product_aliasused'] = 'Alias som ble oppgitt er allerede i bruk';
$lang['error_product_nameused'] = 'Et produkt med det navnet eksisterer allerede';
$lang['error_product_notfound'] = 'Produktet ble ikke funnet';
$lang['error_product_skuused'] = 'Dette V.nr.(SKU) er allerede i bruk av et annet produkt';
$lang['error_price_adjustment'] = 'Ugyldig prisjusteringsverdi for enhet %s';
$lang['error_sku_required'] = 'Vennligst oppgit et unikt V.nr.(SKU) ';
$lang['error_upload_failed'] = 'Opplasting feilet: %s';
$lang['exclude_categories'] = 'Ekskluder produkter i de valgte kategoriene fra resultatene';
$lang['expire_six_months'] = 'Etter seks m&aring;neder';
$lang['expire_one_year'] = 'Etter ett &aring;r';
$lang['expire_two_year'] = 'Etter to &aring;r';
$lang['extra1'] = 'Ekstrafelt 1';
$lang['extra2'] = 'Ekstrafelt 2';
$lang['field'] = 'Felt';
$lang['fields'] = 'Felter';
$lang['fielddef'] = 'Feltdefinisjon';
$lang['fielddefs'] = 'Feltdefinisjoner';
$lang['file'] = 'Fil';
$lang['filters'] = 'Filtre';
$lang['firstpage'] = '<< ';
$lang['general_settings'] = 'Generelle innstillinger';
$lang['go'] = 'Start';
$lang['help'] = '<h3>What does this do?</h3>
<p>This module provides a way to collect, organize, and display information about products and their categories.  This module can stand on its own, or be part of an e-commerce solution if you wish.  The module supports a product existing in more than one category, supports product weight, price, and attribute sets.  Each item in an attribute set can have a price adjustment.  Also a global flag indicates wether the product is &#039;taxable&#039; or not.</p>
  <p>This module provides multiple custom field definitions, and for the ability to discriminate private from public data.</p>
<h3>Features:</h3>
<ul>
  <li>Numerous Views</li>
    <ul>
      <li>Summary view</li>
      <li>Category List View</li>
      <li>Detail view</li> 
      <li>Hierarchy Drill-down View</li>
    </ul>
  <li>Entirely Database Template Driven</li>
  <p>Numerous templates of each type can be defined, defaults specified for each type, and the template used for each particular view can be specified as a parameter</p>
  <li>Sorting and pagination in the summary view</li>
  <li>Products can exist in multiple categories</li>
  <li>Numerous custom fields can be defined, including images</li>
  <li>Automatic thumbnail creation</li>
  <li>Admin defined fields</li>
  <li>Product attributes (including price adjustment)</li>
  <li>Weight and taxable fields (for use in e-commerce solutions)</li>
  <li>Products can have a status (published or draft) in order to hide products from public display at any time</li>
  <li>Pretty URL Support</li>
  <li><strong>More...</strong></li>
</ul>

<h3>How Do I Use It:</h3>
<ul>
<li>Set preferences</li>
<p>Usually this is just a formality.  You should specify your default weight units, and your default currency symbol for your local environment.</p>
<li>Setup users and permissions</li>
<p>This module uses the &#039;Modify Templates&#039; permission to allow users to be able to modify the various templates that can be used by this module.  As well, the &#039;Modify Site Preferences&#039; permission is needed to be able to adjust the modules preferences.  In order to have the ability to modify field definitions, categories, or products, your users will need the &#039;Modify Products&#039; permission.</p>
<li>(optional) Define one or more categories</li>
<p>This is an optional step, but you will probably want to do this early to prevent having to go back to modify each and every product later.  Adding a category is as simple as clicking on the &#039;Categories&#039; tab in the Product Managers admin section, and clicking &#039;Add A Category&#039;.  From there you will be prompted for a category name.</p>
<li>(optional) Define one or more custom fields</li>
<p>This is an optional step.  Custom fields are not needed if this module suits you exactly as it is.  However if you would like to store additional information for each of your products you can create custom fields.  Creating custom fields is similar to creating categories, except that more data is requested.</p>
<p>Currently a number of types of custom fields are available, including: &#039;textbox&#039;,&#039;checkbox&#039;,and &#039;textarea&#039;, &#039;dropdown&#039;, and &#039;file&#039;.  Select one of these, give your new field a name, and indicate wether that field should be visible to the public in the various views.  Then hit submit</p>
<li>Create one or more products</li>
<p>You should create one or more products to display in your website content.  Give each product a name, a price (optional) a weight (optional), a status (draft or published), and some information.  Additionally, you can also specify if the product is taxable.</p>
<p>If categories are defined, then a checkbox will appear for each defined category.  You can simply click the checkbox fields for each category that this product should belong to.</p>
<p>If custom fields are defined, then input fields appropriate to the type of custom field will appear and allow you to specify data for each of them.  This data is optional.</p>
<li>Add the appropriate tags into your page templates or page content</li>
<p>This can be as simple as adding the <strong>{Products}</strong> tag into the content area of one of your pages, or into your page template.</p>
<p>If you wish to alter the behaviour of this application from its default, you can do that by adding one or more parameters to the <strong>{Products}</strong> tag.  The complete list of parameters and their behaviour is listed below.  But for example, to display a list of products in a single, existing category, you could use a tag like <code>{Products category=&#039;categoryname&#039;}</code></p>
</ul>
<h3>Smarty Plugins</h3>
<p>This module also registers one or more smarty plugins to aide in retrieving various products related information when designing products module templates:</p>
<ul>
  <li>{products_getcategory categoryid=&#039;99&#039; [assign=&#039;tmp&#039;]}
  <p>This plugin allows retrieving all of the information for a specific category id and optionally assigning it to the named smarty variable.  The returned is an object containing all of the information about a category, including its field values.<br/>i.e:. <code>{products_getcategory categoryid=1 assign=&#039;tmp&#039;}Category name = {$tmp->name}</code></p>
   
   </p>
  </li>
</ul>
<h3>Support</h3>
<p>This module does not include commercial support.  However there are a number of resources available to help you with it:</p>
<ul>
<li>For the latest version of this module, FAQs or to file a bug report, please visit the cms made simple <a href="http://dev.cmsmadesimple.org">Developers Forge</a> and do a search for &#039;Products&#039;</li>
<li>To obtain commercial support, please send an email to the author at <a href="mailto:calguy1000@cmsmadesimple.org">Robert Campbell</a>.</li>
<li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forms.</a></li>
<li>For some questions and limited technical support, the author can often be found in the <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a>.</li>
</ul>
<h3>Copyright and License</h3>
<p>Copyright &amp;copy; 2008, Robert Campbel <a href="mailto:calguy1000@cmsmadesimple.org">&amp;lt;calguy1000@cmsmadesimple.org&amp;gt;</a>. All Rights Are Reserved.</p>
<p>This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.</p>
<p>However, as a special exception to the GPL, this software is distributed
as an addon module to CMS Made Simple.  You may not use this software
in any Non GPL version of CMS Made simple, or in any version of CMS
Made simple that does not indicate clearly and obviously in its admin 
section that the site was built with CMS Made simple.</p>
<p>This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>';
$lang['hierarchy'] = 'Hierarki';
$lang['hierarchy_position'] = 'Hierarki posisjon';
$lang['hierarchy_settings'] = 'Hierarki innstillinger';
$lang['id'] = 'Id ';
$lang['imagetext'] = 'Bilde';
$lang['image_handling_settings'] = 'Bildebehandlingsinnstillinger';
$lang['import_from_csv'] = 'Importer produkter fra CSV fil';
$lang['inches'] = 'Tommer';
$lang['include_children'] = 'Inkluder barn?';
$lang['info_alnumonly'] = 'Kun alfanummeriske tegn. Ingen mellomrom, anf&oslash;rselstegn eller ikke-bokstav/tall kombinasjoner';
$lang['info_attribtemplate'] = 'Mulige variabler er: ($attrib_text), ($attrib_adjust), ($currency_symbol)';
$lang['info_attributes_copied'] = 'Atributter kopiert';
$lang['info_autowatermark'] = 'Vannmerke innstillingene er hentet fra CGExtensions Modulen';
$lang['info_batchsize'] = 'Sett et antall linjer som skal prosesseres per &quot;batch&quot;. Etter hver batch er ferdig, vil importereren omdirigere, og fortsette operasjonene. Om du opplever minne feil eller tidsavbrudd problemer p&aring; grunn av store mengder i prosessering, so b&oslash;r du kanskje kontakte din din nettstedsvert, eller redusere dette antallet';
$lang['info_cart_module_params'] = 'Disse parametere gis til den valgte handlekurv(cart) modulen fra produkt-detalj og -sammendragsvisningene';
$lang['info_copy_attribsets'] = 'Denne handlingen vil kopiere attributtsett (unntatt sku verdier) fra et annet produkt.';
$lang['info_createfields'] = 'Opprett ukjente produktfelter automatisk? <em>(De vil bli opprettet som tekstfelter)</em>';
$lang['info_createcategories'] = 'Opprett automatisk produktkategorier for &aring; samsvare med de som er i CSV filen, om de ikke allerede eksisterer';
$lang['info_createhierarchy'] = 'Opprett produkthierarkier automatisk for &aring; samsvare med de som er i CSV filen, om de ikke allerede eksisterer';
$lang['info_decimal_units'] = 'Systemet forst&aring;r (.) som desimalseparator (ikke komma!). F.eks.: <strong>5.25</strong>';
$lang['info_delimiter'] = 'Spesifiser bokstaven (eller bokstavene) som separerer hvert felt';
$lang['info_duplicateproducts'] = 'Spesifiser hvordan systemet skal behandle et produkt som har et navn som allerede eksisterer i CSV filen';
$lang['info_fielddefs_tab'] = '<strong>Merk: </strong> Alle felter definert her er tilgjengjelige for alle produkter.';
$lang['info_fieldproblems'] = 'Problemer ble oppdaget under h&aring;ndtering av et eller flere ekstra(custom) felter. Handlingen er vellykket fullf&oslash;rt, men du b&oslash;r unders&oslash;ke og korrigere disse problemene';
$lang['info_handleimages'] = 'Ved import, om et bilde filnavn blir funnet i en feltkolonne, skal det bli fjernet fra kilde lokasjonen, vannmerket, miniatyrbildet, og felttypen endres til &quot;image&quot;';
$lang['info_hierpage'] = 'Bruk denne siden for hierarkivisninger. Dene sideID vil ikke bli spesifisert p&aring; webadressen.';
$lang['info_imagepath'] = 'Stien (relativt til uploads katalogen) hvor bilder referert til i importfilen, kan bli funnet';
$lang['info_imagestuff_deprecated'] = 'Bildebehandlingsfunksjoner er foreldet og vil bli fjernet i en fremtidig versjon. Bruk CGSmartImage for inline bildebehandling.';
$lang['info_import_test_passed'] = 'En kort test har blitt utf&oslash;rt p&aring; den spesifiserte innfilen, og alt ser ut til &aring; v&aelig;re i orden.<br/>Dette er ikke en indikasjon p&aring; at det ikke kan v&aelig;re feil i filen.';
$lang['info_prettyhierurls'] = 'Inkluder hierarki elementnavnet p&aring; URLen';
$lang['info_price_adjustment'] = 'Gyldige verdier er +-*#.##';
$lang['info_prodnotfound'] = 'Dette alternativet bestemmer oppf&oslash;rselen til nettstedet hvis en har g&aring;tt rett til produkt-detaljvisning via en nettadresse, og at produktet av en eller annen grunn (deaktivert, slettet, osv.) ikke kan &aring;pnes.';
$lang['info_publicfield'] = 'Offentlige felt er tilgjengelige &aring; se for alle';
$lang['info_reorder_content'] = 'Denne operasjonen tillater &aring; dra de enkelte noder i treet for &aring; endre rekkef&oslash;lgen de vises p&aring; i hierarkivisning';
$lang['info_setecomhandlers'] = 'Denne knappen vil sikre at hendelsesbehandlerne for e-handel hendelser er p&aring; plass. Dette er nyttig om en ber Produktmodulen om &aring; holde styr p&aring; mengde tilgjengelig, men hendingsaktivatorer ikke ble opprettet under installasjon eller oppgradering';
$lang['label'] = 'Etikett';
$lang['label_skip'] = 'Hopp over';
$lang['label_overwrite'] = 'Overskriv';
$lang['lastpage'] = ' >>';
$lang['last_modified'] = 'Sist endret';
$lang['logotext'] = 'Andre bilde';
$lang['maxlength'] = 'Maksimum lengde <em>(kan benyttes kun p&aring; tekstboks felter)</em>';
$lang['modifieddate'] = 'Endret dato';
$lang['module_description'] = 'En modul for &aring; behandle en katalog med produkter, dets pris, bilder, osv, og for &aring; tillate brukere &aring; bygge en handlekurv';
$lang['move_down'] = 'Flytt ned';
$lang['move_up'] = 'Flytt opp';
$lang['msg_eventhandlers_created'] = 'Hendelsesbehandlere opprettet';
$lang['name'] = 'Navn';
$lang['needpermission'] = 'Du har ikke den n&oslash;dvendige rettigheten: %s';
$lang['new_category_name'] = 'Nytt kategori navn';
$lang['nextpage'] = ' >';
$lang['no'] = 'Nei';
$lang['nonamegiven'] = 'Ingen navn oppgitt';
$lang['none'] = 'Ingen';
$lang['nothing_selectd'] = 'Ingenting valgt';
$lang['of'] = 'av';
$lang['operation_cancelled'] = 'Operasjon avbrutt';
$lang['operation_complete'] = 'Operasjon ferdig';
$lang['page'] = 'Side';
$lang['page_of'] = 'Side %s av %s';
$lang['page_limit'] = 'Side begrensning';
$lang['param_action'] = 'Specify the behaviour of the module.  Possible values are:
<ul>
  <li>hierarchy -- Display a product list by hierarchy</li>
  <li>categorylist - Display a list of product categories</li>
  <li><em>default</em> - Display a summary of products</li>
  <li>details - Display a detail view of a single product</li>
  <li>fieldlist - Display a list of values from a specified field.
     <p>
&nbsp;&nbsp;&nbsp;&nbsp;- This action can be used to create a navigation from the values of a specific field.  i.e:  you could create a custom dropdown field called &amp;quot;color&amp;quot; and then create a navigation based on the different colors.
     </p>
  </li>
  <li>search - Display a form to allow searching products on various criterium</li>
</ul>';
$lang['param_category'] = 'N&aring;r benyttet med <em>standard</em> sammendragsmodus vil denne parameter, som skal v&aelig;re lik navnet p&aring; en eksisterende kategori, bli benyttet for &aring; vise kun de produktene som er i denne kategorien. (en kommaseparert liste kan oppgis) Denne parameteren kan ogs&aring; benyttes med categorylist handlingen for &aring; begrense utdata til de spesifiserte produktkatagoriene.';
$lang['param_categoryfield'] = 'Gjelder kun til &quot;categorylist&quot; handling, hvor denne parameteren kan brukes til &aring; filtrere kategorier basert p&aring; verdien av et kategorifelt. Dette vil ikke fungere i forbindelse med &quot;kategori&quot; eller &quot;category_id&quot; parametere. Syntaksen for denne parameteren er en kommaseparert liste med feltnavn, og feltverdier. dvs.: categorylist=&amp;quot;feltnavnet:verdi,feltnavn2:verdien 2&amp;quot;';
$lang['param_categorylisttemplate'] = 'Med kategoriliste  og fieldlist handlingene, vil denne parameter indikere malen som skal benyttes for visning. Om ingen verdi er oppgitt vil n&aring;v&aelig;rende standard mal av denne type bli benyttet.';
$lang['param_categorylistdtltemplate'] = 'Kan kun benyttes med categorylist handlingene, hvor denne parameteren indikerer malen som skal benyttes for visning av kategoridetaljer. Dette benytter en katagorilistemal.. Om ingen verdi er spesifisert s&aring; vil n&aring;v&aelig;rende standardmal av denne typen bli benyttet.';
$lang['param_detailpage'] = 'Dette spesifiserer sideid&#039;en eller sidealias som skal benyttes for &aring; vise detaljrapporten. Dette kan benyttes med <em>default</em> eller s&oslash;k handlingene.';
$lang['param_detailtemplate'] = 'Denne parameter spesifiserer malen som skal benyttes for detaljmodus visning. Om ingen verdi er oppgitt vil n&aring;v&aelig;rende standard mal av denne type bli benyttet. Denne parameter har ingen virkning n&aring;r vakre urler er p&aring;sl&aring;tt.';
$lang['param_excludecat'] = 'Gjelder kun til standard (sammendrag) visning, hvor denne parameteren vil tillate unntak av produkter som er i en bestemt kategori fra resultatet. En kommaseparert liste med kategorinavn er tillatt. Denne parameteren kan fungere sammen med kategori-parameteren for &aring; gi en liste over produkter som er i denne kategorien, men ikke i den kategorien';
$lang['param_field'] = 'Benyttet kun i <em>fieldlist</em> handlingen, der denne parameter er p&aring;krevd for &aring; spesifisere navnet p&aring; en brukerdefinert egenskap som det skal lages en liste fra.';
$lang['param_fieldval'] = 'Kun benyttet i <em>standard</em> handlinge, hvor denne parameter tillater &aring; spesifisere en feltverdi &aring; begrense resultater etter. Spesialverdier for dette feltet er &quot;::null::&quot; &quot;::notnull::&quot;';
$lang['param_hierarchy'] = 'Kan kun benyttes i <em>default</em> og hierarki handlinger. Denne parameter har to oppgaver - den spesifiserer at kun artikler i denne lokasjonen i hierarkiet skal vises.  Jokertegn kan benyttes s&aring; du ogs&aring; kan spesifisere foreldre/barn relasjoner. F.eks. {Products hierarchy=&#039;trucks*&#039;} vil lage en sammendragsrapport med alle trucks, inkludert barna i hierarkiet.  P&aring; samme m&aring;te, {Products hierarchy=&#039;*trucks&#039;} vil vise en sammendragsrapport med alle trucks og alle produkter tilh&oslash;rende enhver foreldre i hierarkiet. N&aring;r benyttet med hierarkihandlingen s&aring; kan denne parameter gi en liste med hierarkinavn for &aring; vise akkurat disse. F.eks. {Products action=hierarchy hierarchy=&#039;trucks,cars&#039;}';
$lang['param_hierarchytemplate'] = 'Denne parameter spesifiserer malen som skal brukes for hierarki visning. Om ingen verdi er satt vil standard mal av den typen bli benyttet.';
$lang['param_inline'] = 'Kun nyttig for s&oslash;k-handlingen, der denne parameteren spesifiserer at utdata for sammendragesvisningen skal vises inline';
$lang['param_pagelimit'] = 'Benyttet med <em>standard</em> handlingen vil denne parameter spesifisere hvor mange produkter som skal listes p&aring; hver side.';
$lang['param_parent'] = 'Kan kun benyttes i <em>hierarchy</em> handlingen. Denne parameter spesifiserer hierarki id til start posisjonen i rapporten.';
$lang['param_productid'] = 'Benyttet med detalj handlingen vil denne parameter indikere hvilket produkt som skal vises p&aring; siden.';
$lang['param_productlist'] = 'Gjelder kun til standard (sammendrag) visning, hvor denne parameteren kan angi en kommaseparert liste med heltall produkt-IDer &aring; vise. Ingen paginering eller sortering utf&oslash;res da p&aring; disse verdiene. Andre spesifiserte filtreringsparametere, om dette er spesifisert for sammendragsvisningen, vil ogs&aring; ignoreres.';
$lang['param_resultpage'] = 'Kun gyldig for s&oslash;k handlingen, hvor denne parameteren spesifiserer en side-id eller alias &aring; benytte for &aring; vise s&oslash;keresultatene';
$lang['param_searchfield'] = 'Kun gyldig for s&oslash;k handlingen, hvor denne parameteren kan inneholde en kommaseparert liste med feltnavn &aring; inkludere i s&oslash;ket';
$lang['param_searchformtemplate'] = 'Kun gyldig for s&oslash;k handlingen, hvor denne parameteren tillater &aring; spesifisere en ikke-standard s&oslash;keskjemamal';
$lang['param_showall'] = 'Gjelder kun til categorylist og fieldlist handlingene, dersom denne parameteren er satt til en ikke 0 heltallsverdi vil alle kategorier (ogs&aring; de uten produkter) bli vist.';
$lang['param_sortorder'] = 'Specify the order of sorted fields in summary view.  Possible values are:
<ul>
  <li><strong>asc</strong> -- Ascending order</li>
  <li>desc -- Descending order</li>
</ul>';
$lang['param_sortby'] = 'Applicable in the summary, categorylist or search actions, this parameter determines the sorting of the output.  Possible values are:
<ul>
  <li><strong>product_name</strong></li>
  <li>id -- The product id</li>
  <li>weight -- The product weight</li>
  <li>price -- The product base price</li>
  <li>status -- Draft or published</li>
  <li>random -- Display in random order on each request</li>
  <li>created -- The creation date for this company record</li>
  <li>modified -- The modified date for this company record</li>
  <li>f:fieldname -- Allows sorting by values of custom fields.</li>
</ul>
<p>The category list view supports only a few specific sorting options:</p>
<ul>
  <li>id -- The category id.</li>
  <li><strong>name</strong> -- The category name.</li>
</ul>';
$lang['param_sorttype'] = 'Denne parameteren er kun gyldig for standard samemndragsvisningen, hvor denne parameteren benyttes til &aring; konvertere verdiene til en annen type s&aring; de kan benyttes til sortering. Gyldige verdier er STRING,SIGNED og UNSIGNED. Om dette ikke er satt her s&aring; vil standardtypen STRING bli benyttet.';
$lang['param_summarypage'] = 'Denne parameter er kun aktuell for action=hierarchy, hvor den tillater &aring; spesifisere en sideID eller alias som vil bli benyttet for alle lenker for sammendragsvisning';
$lang['param_summarytemplate'] = 'Denne parameter spesifiserer malen som skal benyttes for sammendragsmodus visningen. Om ingen verdi er oppgitt vil n&aring;v&aelig;rende standard mal av denne type bli benyttet.';
$lang['parent'] = 'Foreldre';
$lang['postinstall'] = 'Products modulen har blitt installert';
$lang['postuninstall'] = 'Products modulen og alle assosierte data har blitt fjernet';
$lang['preferences'] = 'Preferanser';
$lang['preuninstall'] = '&Aring; fjerne denne modulen vil ogs&aring; fjerne alle assosierte data, er du sikker p&aring; at du vil fortsette?';
$lang['price'] = 'Pris';
$lang['price_adjustment'] = 'Prisjustering';
$lang['prevpage'] = '< ';
$lang['product'] = 'Produkt';
$lang['productname'] = 'Produktnavn';
$lang['products'] = 'Produkt administrasjon';
$lang['product_detail_settings'] = 'Produkt detaljinnstillinger';
$lang['product_editing_settings'] = 'Produktredigerings innstillinger';
$lang['product_summary_settings'] = 'Produktsammendrag innstillinger';
$lang['product_hierarchy'] = 'Produkt hierarki';
$lang['product_info'] = 'Produktinformasjon';
$lang['product_manager'] = 'Produkt behandler';
$lang['progress'] = 'Fremdrift';
$lang['prompt'] = 'Etikett (sp&oslash;rsm&aring;l/prompt)';
$lang['prompt_add_attribset'] = 'Legg til/rediger atributtsett';
$lang['prompt_allowed_filetypes'] = 'Tillat opplasting av file med disse filendelser (for fil type felter)';
$lang['prompt_allowed_imagetypes'] = 'Tillat opplasting av bilder med disse filendelser (for bilde type felter)';
$lang['prompt_attribtemplate'] = 'Mal for visning av produktets attributtverdier i nedtrekk';
$lang['prompt_autothumbnail'] = 'Opprett miniatyrbilder automatisk fra bilder';
$lang['prompt_autothumbnail_size'] = 'Maksimum st&oslash;rrelse (st&oslash;rste dimensjon) for miniatyrbildet.';
$lang['prompt_autopreviewimg'] = 'Lag forh&aring;ndsvisningsbilder automatisk av bildene';
$lang['prompt_autopreviewimg_size'] = 'Maksimum st&oslash;rrelse (st&oslash;rste dimensjon) for forh&aring;ndsvisningsbildet.';
$lang['prompt_autowatermark'] = 'Plasser vannmerker p&aring; bilder automatisk';
$lang['prompt_applicable'] = 'Sl&aring; p&aring; som standard for alle nye produkter';
$lang['prompt_batchsize'] = 'Batch st&oslash;rrelse';
$lang['prompt_cart_module'] = 'Handlekurv(cart) modul';
$lang['prompt_cart_module_params'] = 'Handlekurv(cart) modul parametere';
$lang['prompt_createcategories'] = 'Opprett kategorier';
$lang['prompt_createfields'] = 'Opprett produktkategorier?';
$lang['prompt_createhierarchy'] = 'Opprett produktkategori';
$lang['prompt_csvfile'] = 'Last opp CSV fil';
$lang['prompt_currencycode'] = 'Valutakode';
$lang['prompt_currencysymbol'] = 'Valutasymbol';
$lang['prompt_default_status'] = 'Som standard har alle nye produkter denne statusen';
$lang['prompt_default_taxable'] = 'Som standard er alle nye produkter avgiftspliktige';
$lang['prompt_deleteproductfiles'] = 'Slett alle filer tilknyttet produktet n&aring;r produktet slettes?';
$lang['prompt_delimiter'] = 'Felt skilletegn';
$lang['prompt_detailpage'] = 'Standard detaljside';
$lang['prompt_detailsfor'] = 'Detaljer fo %s';
$lang['prompt_duplicateproducts'] = 'Hvordan skal duplikate produkter behandles?';
$lang['prompt_false'] = 'Usann';
$lang['prompt_handleimages'] = 'Behandle bilder?';
$lang['prompt_imagepath'] = 'Bildesti';
$lang['prompt_lengthunits'] = 'Lengdeenheter';
$lang['prompt_notfound_behavior'] = 'Hvilken handling skal utf&oslash;res om et produkt ikke kan vises?';
$lang['prompt_notfound_404'] = 'Generer en 404 feil';
$lang['prompt_notfound_301'] = 'Generer en 301 omdirigering';
$lang['prompt_notfound_errormsg'] = 'Vis en feilmelding';
$lang['prompt_notfound_msg'] = 'Feilmelding for n&aring;r et produkt ikke blir funnet';
$lang['prompt_notfound_page'] = 'Side &aring; omdirigere til permanent?';
$lang['prompt_hierpage'] = 'Standardside for hierarkivisning';
$lang['prompt_prettyhierurls'] = 'Benytt vakre URLer for hierarkivisningene';
$lang['prompt_prod_detailpage'] = 'Standardside for Product detaljvisning';
$lang['prompt_products_matching'] = 'Produkter som passer %s';
$lang['prompt_sku_required'] = 'V.nr.(SKU) er p&aring;krevd for alle produkter og attributter';
$lang['prompt_summarypagelimit'] = 'Standard sidegrense i sammendragsmodus';
$lang['prompt_summarysortorder'] = 'Standard sortering i sammendragsmodus';
$lang['prompt_summarysorting'] = 'Standard sorteringsfelt i sammendragsmodus';
$lang['prompt_template'] = 'Malkilde';
$lang['prompt_true'] = 'Sann';
$lang['prompt_urlprefix'] = 'Prefiks til bruk p&aring; alle nettadresser m&aring;lrettet til denne denne modulen';
$lang['prompt_use_detailpage_for_search'] = 'Benytt denne siden for s&oslash;keresultater ogs&aring; <em>(overstyrer searchresults sideparameteren i s&oslash;kemodulen)</em>';
$lang['prompt_usehierpathurls'] = 'Benytt hierakisti i Product detalj URLer';
$lang['prompt_weightunits'] = 'Vektenheter';
$lang['public'] = 'Er dette et offentlig felt?';
$lang['published'] = 'Publisert';
$lang['quantity_on_hand'] = 'Mengde tilgjengelig';
$lang['random'] = 'Tilfeldig';
$lang['reorder_hierarchy'] = 'Omorganiser hierarki';
$lang['resettofactory'] = 'Sett tilbake til fabrikkinnstillinger';
$lang['return'] = 'Tilbake';
$lang['return_to_top'] = 'Returner til toppen av visningen';
$lang['root'] = 'Rota';
$lang['search_description'] = 'S&oslash;keegenskap beskrivelse';
$lang['search_expr'] = 'Skal sp&oslash;rringen passe alle eller noen av kriteriene nedenfor?';
$lang['search_name'] = 'S&oslash;keegenskapsnavn';
$lang['search_price'] = 'Prisintervall';
$lang['searchtemplate_addedit'] = 'Legg til/rediger S&oslash;keskjemamal';
$lang['searchtemplates'] = 'S&oslash;ke maler';
$lang['select_all'] = 'Velg alle';
$lang['select_one'] = 'Velg en';
$lang['setdraft'] = 'Sett som kladd';
$lang['setpublished'] = 'Sett som publisert';
$lang['sku'] = 'V.nr.(SKU)';
$lang['sort_by'] = 'Sorter etter';
$lang['sort_order'] = 'Sorteringsrekkef&oslash;lge';
$lang['source'] = 'Kilde';
$lang['status'] = 'Status ';
$lang['submit'] = 'Utf&oslash;r';
$lang['subscription'] = 'Abonnement';
$lang['subscr_expiry'] = 'Utl&oslash;per';
$lang['subscr_expiry2'] = 'Utl&oslash;per';
$lang['subscr_monthly'] = 'M&aring;nedlig';
$lang['subscr_delperiod'] = 'Deveringsfrekvens';
$lang['subscr_delperiod2'] = 'Levert';
$lang['subscr_payperiod'] = 'Betalingsfrekvens';
$lang['subscr_payperiod2'] = 'Betalt';
$lang['subscr_quarterly'] = 'Kvartalsvis';
$lang['subscr_semianually'] = 'Halv&aring;rlig';
$lang['subscr_yearly'] = '&Aring;rlig';
$lang['summarytemplates'] = 'Sammendragsmal';
$lang['summarytemplate_addedit'] = 'Legg til/rediger sammendragsmal';
$lang['taxable'] = 'Kan ilegges avgift';
$lang['test'] = 'Test ';
$lang['textarea'] = 'Tekstomr&aring;de';
$lang['textbox'] = 'Tekst innskriving';
$lang['title_byhierarchy_dflttemplate'] = 'Standard Hierarki rapportmal';
$lang['title_categorylist_dflttemplate'] = 'Standard ny kategorilistemal';
$lang['title_detail_dflttemplate'] = 'Standard ny detaljmal';
$lang['title_search_dflttemplate'] = 'Standard ny s&oslash;kemal';
$lang['title_summary_dflttemplate'] = 'Standard ny sammendragsmal';
$lang['type'] = 'Type ';
$lang['up'] = 'Flytt opp';
$lang['update'] = 'Oppdater';
$lang['upload'] = 'Velg en fil &aring; laste opp';
$lang['url_alias'] = 'URL alias';
$lang['valid'] = 'Gyldig';
$lang['value'] = 'Verdi';
$lang['values'] = 'Verdier';
$lang['view'] = 'Vis';
$lang['viewable_fields'] = 'Velg brukerdefinerte felter som skal vises i tabellen';
$lang['watermark_location'] = 'Vannmerke lokasjon';
$lang['weight'] = 'Vekt';
$lang['with_selected'] = 'Med valgte';
$lang['yes'] = 'Ja';
$lang['qca'] = 'P0-536849115-1307983495210';
$lang['utma'] = '156861353.771487945.1315514710.1315743680.1315755952.10';
$lang['utmz'] = '156861353.1315514710.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353.2.10.1315755952';
?>